Package: ei
Version: 1.3-3
Date: 2016-11-04
Title: Ecological Inference
Author: Gary King <king@harvard.edu>, Molly Roberts <molly.e.roberts@gmail.com>
Maintainer: James Honaker <zelig.zee@gmail.com>
Depends: R (>= 2.5.0), eiPack
Imports: mvtnorm, msm, tmvtnorm, ellipse, plotrix, MASS, ucminf,
        cubature, mnormt, foreach, sp
Suggests: rgl
Description: Software accompanying Gary King's book: A Solution to the Ecological Inference Problem. (1997). Princeton University Press. ISBN 978-0691012407. 
License: GPL (>= 2)
URL: http://gking.harvard.edu/eiR,
        http://gking.harvard.edu/eicamera/kinroot.html
NeedsCompilation: no
Packaged: 2016-11-04 22:19:49 UTC; tercer
Repository: CRAN
Date/Publication: 2016-11-05 00:49:10
Built: R 4.6.0; ; 2026-04-26 12:53:18 UTC; unix
